pub async fn forward_legacy_high_qc<T: NodeType>(
legacy_event_rx: InactiveReceiver<Event<T>>,
client_api: ClientApi<T>,
upgrade_lock: UpgradeLock<T>,
)Expand description
Forward the last legacy view’s QC into the coordinator, so the cutover-view leader can propose on it instead of waiting out a timeout when the cutover seed was snapshotted before the QC formed.